pub enum MissingInput {
NotRegistered {
name: String,
},
TypeMismatch {
name: String,
expected: &'static str,
actual: &'static str,
},
}Expand description
Error returned when a named input is missing or stored under a different type.
Variants
NotRegistered
No input was registered for the given name.
TypeMismatch
An input is registered but stored under a different type.