pub struct ArgSource { /* private fields */ }Expand description
Collect input from a CLI argument.
This source reads a string value from a clap argument. It is available when the argument was provided by the user.
Example
ⓘ
use standout_input::{InputChain, ArgSource};
// For: myapp --message "hello"
let chain = InputChain::<String>::new()
.try_source(ArgSource::new("message"));Implementations