ClipboardSource

Struct ClipboardSource 

pub struct ClipboardSource<R: ClipboardReader = RealClipboard> { /* private fields */ }
Collect input from the system clipboard.

This source reads text from the system clipboard. It is available when the clipboard contains non-empty text content.

Platform Support

  • macOS: Uses pbpaste
  • Linux: Uses xclip -selection clipboard -o
  • Other: Returns an error

Example

use standout_input::{InputChain, ArgSource, ClipboardSource};

let chain = InputChain::<String>::new()
    .try_source(ArgSource::new("content"))
    .try_source(ClipboardSource::new());

Testing

Use ClipboardSource::with_reader to inject a mock for testing:

use standout_input::{ClipboardSource, MockClipboard};

let source = ClipboardSource::with_reader(MockClipboard::with_content("clipboard text"));

Implementations

Source

impl ClipboardSource<RealClipboard>

pub fn new() -> Self

Create a new clipboard source using real system clipboard.

Source

impl<R: ClipboardReader> ClipboardSource<R>

pub fn with_reader(reader: R) -> Self

Create a clipboard source with a custom reader.

This is primarily used for testing to inject mock clipboard.

pub fn trim(self, trim: bool) -> Self

Control whether to trim whitespace from the clipboard content.

Default is true.