ConfirmPromptSource

Struct ConfirmPromptSource 

pub struct ConfirmPromptSource<T: TerminalIO = RealTerminal> { /* private fields */ }
Simple yes/no confirmation prompt.

Prompts the user for a yes/no response. Accepts y/yes/n/no (case-insensitive).

Example

use standout_input::{InputChain, FlagSource, ConfirmPromptSource};

let chain = InputChain::<bool>::new()
    .try_source(FlagSource::new("yes"))
    .try_source(ConfirmPromptSource::new("Proceed?"));

let confirmed = chain.resolve(&matches)?;

Implementations

Source

impl ConfirmPromptSource<RealTerminal>

pub fn new(prompt: impl Into<String>) -> Self

Create a new confirmation prompt.

Source

impl<T: TerminalIO> ConfirmPromptSource<T>

pub fn with_terminal(prompt: impl Into<String>, terminal: T) -> Self

Create a confirm prompt with a custom terminal for testing.

pub fn default(self, default: bool) -> Self

Set a default value for when the user presses Enter without input.

The prompt suffix will change to indicate the default:

  • None: [y/n]
  • Some(true): [Y/n]
  • Some(false): [y/N]