pub struct DefaultSource<T: Clone + Send + Sync> { /* private fields */ }Expand description
Provide a default value when no other source has input.
This source is always available and always returns the configured value. It should typically be the last source in a chain.
Example
ⓘ
use standout_input::{InputChain, ArgSource, DefaultSource};
let chain = InputChain::<String>::new()
.try_source(ArgSource::new("message"))
.try_source(DefaultSource::new("default message"));Implementations