pub struct MockTerminal { /* private fields */ }Expand description
Mock terminal for testing prompts.
Implementations
Sourceimpl MockTerminal
impl MockTerminal
Sourcepub fn non_terminal() -> Self
pub fn non_terminal() -> Self
Create a mock that simulates a non-terminal.
Sourcepub fn with_response(response: impl Into<String>) -> Self
pub fn with_response(response: impl Into<String>) -> Self
Create a mock terminal that returns the given response.
Sourcepub fn with_responses(
responses: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_responses( responses: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Create a mock terminal that returns multiple responses in sequence.
Useful for testing retry scenarios.