StdinSource

Struct StdinSource 

pub struct StdinSource<R: StdinReader = RealStdin> { /* private fields */ }
Collect input from piped stdin.

This source reads from stdin only when it is piped (not a terminal). If stdin is a TTY, the source returns None to allow the chain to continue to the next source.

Example

use standout_input::{InputChain, ArgSource, StdinSource};

// For: echo "hello" | myapp
let chain = InputChain::<String>::new()
    .try_source(ArgSource::new("message"))
    .try_source(StdinSource::new());

Testing

Use StdinSource::with_reader to inject a mock for testing:

use standout_input::{StdinSource, MockStdin};

let source = StdinSource::with_reader(MockStdin::piped("test input"));

Implementations

Source

impl StdinSource<RealStdin>

pub fn new() -> Self

Create a new stdin source using real stdin.

Source

impl<R: StdinReader> StdinSource<R>

pub fn with_reader(reader: R) -> Self

Create a stdin source with a custom reader.

This is primarily used for testing to inject mock stdin.

pub fn trim(self, trim: bool) -> Self

Control whether to trim whitespace from the input.

Default is true.