Module env

Module env 

Environment abstractions for testability.

This module provides traits that abstract over OS interactions, allowing tests to run without depending on actual terminal state, stdin piping, or clipboard contents.

Structs

MockClipboard
Mock clipboard reader for testing.
MockEnv
Mock environment variable reader for testing.
MockStdin
Mock stdin reader for testing.
RealClipboard
Real clipboard reader using platform commands.
RealEnv
Real environment variable reader.
RealStdin
Real stdin reader using std::io.

Traits

ClipboardReader
Abstraction over clipboard access.
EnvReader
Abstraction over environment variables.
StdinReader
Abstraction over stdin reading.